# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

DEFAULT_TIMEOUT_MS = 10000
DEFAULT_NAMESPACE_NAME = 'default'
DEFAULT_MARQUEZ_BACKEND = 'http'
DEFAULT_MARQUEZ_URL = 'http://localhost:5000'
DEFAULT_MARQUEZ_FILE = '/tmp/marquez/client.requests.log'
DEFAULT_LIMIT = 100
DEFAULT_OFFSET = 0

API_PATH_V1 = '/api/v1'
